package xdgIcons

import "git.tebibyte.media/tomo/tomo"

// icons that can't be directly translated with regex
var xdgIconNames = map[tomo.Icon] string {
	tomo.IconUnknown:                      "image-missing",
	tomo.IconFileNew:                      "document-new",
	tomo.IconDirectoryNew:                 "folder-new",
	tomo.IconFileOpen:                     "document-open",
	tomo.IconFileOpenRecent:               "document-open-recent",
	tomo.IconFilePageSetup:                "document-page-setup",
	tomo.IconFilePrint:                    "document-print",
	tomo.IconFilePrintPreview:             "document-print-preview",
	tomo.IconFilePermissions:              "document-permissions",        // non-standard
	tomo.IconFileProperties:               "document-properties",
	tomo.IconFileRename:                   "document-rename",             // non-standard
	tomo.IconFileRevert:                   "document-revert",
	tomo.IconFileSave:                     "document-save",
	tomo.IconFileSaveAs:                   "document-save-as",
	tomo.IconFileSend:                     "document-send",
	tomo.IconFormatAlignCenter:            "format-justify-center",
	tomo.IconFormatAlignEven:              "format-justify-fill",
	tomo.IconFormatAlignLeft:              "format-justify-left",
	tomo.IconFormatAlignRight:             "format-justify-right",
	tomo.IconMailReceive:                  "mail-send-receive",
	tomo.IconValueIncrement:               "list-add",
	tomo.IconValueDecrement:               "list-remove",
	tomo.IconValueReset:                   "value-reset",                 // non-standard
	tomo.IconApplication:                  "system-run",
	tomo.IconApplicationWebBrowser:        "web-browser",
	tomo.IconApplicationMesssanger:        "internet-messanger",          // non-standard
	tomo.IconApplicationPhone:             "accessories-phone",           // non-standard
	tomo.IconApplicationMail:              "internet-mail-client",        // non-standard
	tomo.IconApplicationTerminalEmulator:  "utilities-terminal",
	tomo.IconApplicationFileBrowser:       "system-file-manager",
	tomo.IconApplicationTextEditor:        "accessories-text-editor",
	tomo.IconApplicationDocumentViewer:    "office-document-viewer",      // non-standard
	tomo.IconApplicationWordProcessor:     "office-word-processor",       // non-standard
	tomo.IconApplicationSpreadsheet:       "office-spreadsheet",          // non-standard
	tomo.IconApplicationSlideshow:         "office-slideshow",            // non-standard
	tomo.IconApplicationCalculator:        "accessories-calculator",
	tomo.IconApplicationPreferences:       "preferences-system",
	tomo.IconApplicationProcessManager:    "utilities-system-monitor",
	tomo.IconApplicationSystemInformation: "distributor-logo",            // non-standard
	tomo.IconApplicationManual:            "help-browser",
	tomo.IconApplicationCamera:            "accessories-camera",          // non-standard
	tomo.IconApplicationImageViewer:       "graphics-image-viewer",       // non-standard
	tomo.IconApplicationMediaPlayer:       "audio-video-media-player",    // non-standard
	tomo.IconApplicationImageEditor:       "graphics-image-editor",       // non-standard
	tomo.IconApplicationAudioEditor:       "audio-audio-editor",          // non-standard
	tomo.IconApplicationVideoEditor:       "video-video-editor",          // non-standard
	tomo.IconApplicationClock:             "accessories-clock",           // non-standard
	tomo.IconApplicationCalendar:          "accessories-calendar",        // non-standard
	tomo.IconApplicationChecklist:         "accessories-checklist",       // non-standard
	tomo.IconApplications:                 "applications-other",
	tomo.IconPreferences:                  "preferences-other",
	tomo.IconPreferencesNetwork:           "preferences-system-network",
	tomo.IconDevice:                       "device",                      // non-standard
	tomo.IconDeviceCamera:                 "camera-photo",
	tomo.IconDeviceWebCamera:              "camera-web",
	tomo.IconDeviceComputer:               "computer",
	tomo.IconDevicePda:                    "pda",
	tomo.IconDevicePhone:                  "phone",
	tomo.IconDevicePrinter:                "printer",
	tomo.IconDeviceScanner:                "scanner",
	tomo.IconDeviceMultimediaPlayer:       "multimedia-player",
	tomo.IconDeviceVideoDisplay:           "video-display",
	tomo.IconDeviceAudioInput:             "audio-input-microphone",
	tomo.IconDeviceAudioOutput:            "audio-speakers",
	tomo.IconHardware:                     "card",                        // non-standard
	tomo.IconHardwareCPU:                  "cpu",
	tomo.IconHardwareGPU:                  "video-card",
	tomo.IconHardwareRAM:                  "ram",
	tomo.IconHardwareSoundCard:            "audio-card",
	tomo.IconHardwareNetworkAdapter:       "network-card",
	tomo.IconPowerBattery:                 "battery",
	tomo.IconStorageHardDisk:              "drive-harddisk",
	tomo.IconStorageFloppyDisk:            "media-floppy",
	tomo.IconStorageSolidState:            "drive-solid",
	tomo.IconStorageOptical:               "media-optical",
	tomo.IconStorageFlashStick:            "media-removable",
	tomo.IconStorageFlashCard:             "media-flash",
	tomo.IconStorageMagneticTape:          "media-tape",
	tomo.IconEmblemReadOnly:               "emblem-readonly",
	tomo.IconPlaceDirectory:               "folder",
	tomo.IconPlaceRemote:                  "folder-remote",
	tomo.IconPlaceHome:                    "user-home",
	tomo.IconPlaceDownloads:               "folder-downloads",            // common
	tomo.IconPlaceDesktop:                 "user-desktop",
	tomo.IconPlacePhotos:                  "folder-pictures",             // common
	tomo.IconPlaceBooks:                   "folder-books",                // non-standard
	tomo.IconPlaceBookmarks:               "user-bookmarks",
	tomo.IconPlaceTrash:                   "user-trash",
	tomo.IconPlaceDocuments:               "folder-documents",            // common
	tomo.IconPlaceRepositories:            "folder-repositories",         // non-standard
	tomo.IconPlaceMusic:                   "folder-music",                // common
	tomo.IconPlaceArchives:                "folder-archives",             // non-standard
	tomo.IconPlaceFonts:                   "folder-fonts",                // non-standard
	tomo.IconPlaceBinaries:                "folder-executables",          // non-standard
	tomo.IconPlaceVideos:                  "folder-videos",               // common
	tomo.IconPlace3DObjects:               "folder-3d-objects",           // non-standard
	tomo.IconPlaceHistory:                 "folder-history",              // non-standard
	tomo.IconPlacePreferences:             "preferences-other",
	tomo.IconDirectoryDragAccept:          "folder-drag-accept",
	tomo.IconDirectoryFull:                "folder-full",
	tomo.IconDirectoryOpen:                "folder-open",
	tomo.IconDirectoryVisiting:            "folder-visiting",
	tomo.IconTrashFull:                    "user-trash-full",
	tomo.IconResourceLoading:              "image-loading",
	tomo.IconResourceMissing:              "image-missing",
	tomo.IconCellularSignal0:              "nm-signal-00",                // common
	tomo.IconCellularSignal1:              "nm-signal-25",                // common
	tomo.IconCellularSignal2:              "nm-signal-75",                // common
	tomo.IconCellularSignal3:              "nm-signal-100",               // common
	tomo.IconWirelessSignal0:              "wifi-signal-00",              // common
	tomo.IconWirelessSignal1:              "wifi-signal-25",              // common
	tomo.IconWirelessSignal2:              "wifi-signal-75",              // common
	tomo.IconWirelessSignal3:              "wifi-signal-100",             // common
	tomo.IconPrintError:                   "printer-error",
	tomo.IconPrintPrinting:                "printer-printing",
	tomo.IconBattery0:                     "battery-caution",
	tomo.IconBattery1:                     "battery-low",
	tomo.IconBattery2:                     "battery-good",                // common
	tomo.IconBattery3:                     "battery-full",                // common
	tomo.IconBrightness0:                  "brightness-dim",              // non-standard
	tomo.IconBrightness1:                  "brightness-medium",           // non-standard
	tomo.IconBrightness2:                  "brightness-bright",           // non-standard
	tomo.IconBrightness3:                  "brightness-full",             // non-standard
	tomo.IconVolume0:                      "audio-volume-muted",
	tomo.IconVolume1:                      "audio-volume-low",
	tomo.IconVolume2:                      "audio-volume-medium",
	tomo.IconVolume3:                      "audio-volume-high",
	tomo.IconPlaylistRepeat:               "media-playlist-repeat",
	tomo.IconPlaylistShuffle:              "media-playlist-shuffle",
}
